@@ -1,4 +1,7 @@
 // RegisteringDynamic Symbols
+#ifndef R_NO_REMAP
+#  define R_NO_REMAP
+#endif
 
 #include <R.h>
 #include <Rinternals.h>
